@@ -2,7 +2,7 @@ from version import ELECTRUM_VERSION
 from util import format_satoshis, print_msg, print_error, set_verbosity
 from wallet import Synchronizer, WalletStorage, Wallet, Imported_Wallet
 from coinchooser import COIN_CHOOSERS
-from network import Network, DEFAULT_SERVERS, DEFAULT_PORTS, pick_random_server
+from network import Network, pick_random_server
 from interface import Connection, Interface
 from simple_config import SimpleConfig, get_config, set_config
 import bitcoin
