@@ -25,6 +25,7 @@
 
 
 from threading import Lock
+import hashlib
 
 from bitcoin import Hash, hash_encode
 from transaction import Transaction
@@ -78,13 +79,21 @@ class Synchronizer(ThreadJob):
                        addresses)
             self.network.send(msgs, self.addr_subscription_response)
 
+    def get_status(self, h):
+        if not h:
+            return None
+        status = ''
+        for tx_hash, height in h:
+            status += tx_hash + ':%d:' % height
+        return hashlib.sha256(status).digest().encode('hex')
+
     def addr_subscription_response(self, response):
         params, result = self.parse_response(response)
         if not params:
             return
         addr = params[0]
         history = self.wallet.get_address_history(addr)
-        if self.wallet.get_status(history) != result:
+        if self.get_status(history) != result:
             if self.requested_histories.get(addr) is None:
                 self.requested_histories[addr] = result
                 self.network.send([('blockchain.address.get_history', [addr])],
@@ -102,6 +111,9 @@ class Synchronizer(ThreadJob):
         server_status = self.requested_histories[addr]
         hashes = set(map(lambda item: item['tx_hash'], result))
         hist = map(lambda item: (item['tx_hash'], item['height']), result)
+        # tx_fees
+        tx_fees = [(item['tx_hash'], item.get('fee')) for item in result]
+        tx_fees = dict(filter(lambda x:x[1] is not None, tx_fees))
         # Note if the server hasn't been patched to sort the items properly
         if hist != sorted(hist, key=lambda x:x[1]):
             self.network.interface.print_error("serving improperly sorted address histories")
@@ -109,11 +121,11 @@ class Synchronizer(ThreadJob):
         if len(hashes) != len(result):
             self.print_error("error: server history has non-unique txids: %s"% addr)
         # Check that the status corresponds to what was announced
-        elif self.wallet.get_status(hist) != server_status:
+        elif self.get_status(hist) != server_status:
             self.print_error("error: status mismatch: %s" % addr)
         else:
             # Store received history
-            self.wallet.receive_history_callback(addr, hist)
+            self.wallet.receive_history_callback(addr, hist, tx_fees)
             # Request transactions we don't have
             self.request_missing_txs(hist)
         # Remove request; this allows up_to_date to be True
@@ -168,7 +180,7 @@ class Synchronizer(ThreadJob):
 
         if self.requested_tx:
             self.print_error("missing tx", self.requested_tx)
-        self.subscribe_to_addresses(set(self.wallet.addresses(True)))
+        self.subscribe_to_addresses(set(self.wallet.get_addresses()))
 
     def run(self):
         '''Called from the network proxy thread main loop.'''
